<?php

class AdelantoSystemClass {

  private $o_ParamBean;
  
  public function __construct($o_ParamBean){
    $this->o_ParamBean = $o_ParamBean;
  }
  
  private function getObjParamBean(){
    return $this->o_ParamBean;
  }
  
  public function insertAdelanto(){
    
    $o_AdelantoBL = new AdelantoBL();
    return $o_AdelantoBL->insertarAdelanto($this->getObjParamBean());
    
  }
  
  public function insertUsuario($o_UsuarioBean){
    $o_UsuarioBL = new UsuarioBL();
    $o_UsuarioBL->insertarUsuario($o_UsuarioBean);
  }
   
  public function eliminarAdelanto(){
    
    $o_AdelantoBL = new AdelantoBL();
    return $o_AdelantoBL->eliminarAdelanto($this->getObjParamBean());
    
  }
  
  public function actualizarAdelanto(){
    
    $o_AdelantoBL = new AdelantoBL();
    return $o_AdelantoBL->modificarAdelanto($this->getObjParamBean());
    
  }
  
  public function getAdelanto(){
  
    $o_AdelantoBL = new AdelantoBL();
    return $o_AdelantoBL->busquedaAdelanto($this->getObjParamBean());
  
  }
   
  public function getColaborador(){
    $o_ColaboradorBL = new ColaboradorBL();
    return $o_ColaboradorBL->busquedaColaborador($this->getObjParamBean());
    
  }
  public function getGrado(){
    $o_GradoBL = new GradoBL();
    return $o_GradoBL->busquedaGrado(new GradoBean());
    
  }
  /*public function getColaborador(){
    
    $o_ColaboradorBL = new ColaboradorBL();
    return $o_ColaboradorBL->getbusquedaColaborador($this->getObjParamBean());
  }*/
  
  public function getEspecialidad(){
    
    $o_EspecialidadBL = new EspecialidadBL();
    return $o_EspecialidadBL->getEspecialidad($this->getObjParamBean());
  }

}